@@ -1,5 +1,5 @@
 package CPAN::Perl::Releases;
-$CPAN::Perl::Releases::VERSION = '1.68';
+$CPAN::Perl::Releases::VERSION = '2.00';
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
 
 use strict;
@@ -140,6 +140,22 @@ our $data =
 "5.19.9" => { id => 'TONYC' },
 "5.19.10" => { id => 'ARC' },
 "5.19.11" => { id => 'SHAY' },
+"5.20.0-RC1" => { id => 'RJBS' },
+"5.20.0" => { id => 'RJBS' },
+"5.21.0" => { id => 'RJBS' },
+"5.21.1" => { id => 'WOLFSAGE' },
+"5.21.2" => { id => 'ABIGAIL' },
+"5.21.3" => { id => 'PCM' },
+"5.20.1-RC1" => { id => 'SHAY' },
+"5.20.1-RC2" => { id => 'SHAY' },
+"5.20.1" => { id => 'SHAY' },
+"5.18.3-RC1" => { id => 'RJBS' },
+"5.21.4" => { id => 'SHAY' },
+"5.18.3-RC2" => { id => 'RJBS' },
+"5.18.3" => { id => 'RJBS' },
+"5.18.4" => { id => 'RJBS' },
+"5.21.5" => { id => 'ABIGAIL' },
+"5.21.6" => { id => 'BINGOS', xz => 1 },
 };
 
 sub perl_tarballs {
@@ -158,6 +174,7 @@ sub perl_tarballs {
   my $foo = { };
   $foo->{'tar.gz'} = "$path/$perl.tar.gz" unless $onlybz2;
   $foo->{'tar.bz2'} = "$path/$perl.tar.bz2" unless $onlygz;
+  $foo->{'tar.xz'} = "$path/$perl.tar.xz" if $data->{ $vers }->{xz};
   $cache->{ $vers } = $foo;
   return { %$foo };
 }
@@ -196,7 +213,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 1.68
+version 2.00
 
 =head1 SYNOPSIS
 
@@ -238,6 +255,8 @@ on CPAN where the indicated tarball will be located.
 
 Not all C<perl> releases had C<tar.bz2>, but only a C<tar.gz>.
 
+Perl tarballs may also be compressed using C<xz> and therefore have a C<tar.xz> entry.
+
 =item C<perl_versions>
 
 Returns the list of all the perl versions supported by the module in ascending order. C<TRIAL> and C<RC> will be lower
